/*
 * Copyright (C) 2023 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */
package de.ozgcloud.apilib.alfa;

import java.time.ZonedDateTime;
import java.util.Map;

import de.ozgcloud.apilib.common.command.OzgCloudCommand;
import de.ozgcloud.apilib.common.command.OzgCloudCommandService;
import de.ozgcloud.apilib.vorgang.OzgCloudVorgangId;
import lombok.RequiredArgsConstructor;

@RequiredArgsConstructor
public class CommandAlfaService implements AlfaService {

	private final OzgCloudCommandService commandService;

	@Override
	public void addAktenNotiz(OzgCloudVorgangId vorgangId, String text) {
		var command = createCreateItemCommand(vorgangId, text);

		commandService.createAndWaitUntilDone(command);
	}

	OzgCloudCommand createCreateItemCommand(OzgCloudVorgangId vorgangId, String text) {
		Map<String, Object> item = Map.of("text", text,
				"createdAt", ZonedDateTime.now().toString());
		Map<String, Object> commandBody = Map.of("item", item,
				"vorgangId", vorgangId.toString(),
				"itemName", "Kommentar",
				"client", "Alfa");

		return OzgCloudCommand.builder()
				.order("CREATE_ATTACHED_ITEM")
				.vorgangId(vorgangId)
				.relationId(vorgangId)
				.bodyObject(commandBody)
				.build();
	}
}
