/*
 * Copyright (C) 2024 Das Land Schleswig-Holstein vertreten durch den
 * Ministerpräsidenten des Landes Schleswig-Holstein
 * Staatskanzlei
 * Abteilung Digitalisierung und zentrales IT-Management der Landesregierung
 *
 * Lizenziert unter der EUPL, Version 1.2 oder - sobald
 * diese von der Europäischen Kommission genehmigt wurden -
 * Folgeversionen der EUPL ("Lizenz");
 * Sie dürfen dieses Werk ausschließlich gemäß
 * dieser Lizenz nutzen.
 * Eine Kopie der Lizenz finden Sie hier:
 *
 * https://joinup.ec.europa.eu/collection/eupl/eupl-text-eupl-12
 *
 * Sofern nicht durch anwendbare Rechtsvorschriften
 * gefordert oder in schriftlicher Form vereinbart, wird
 * die unter der Lizenz verbreitete Software "so wie sie
 * ist", OHNE JEGLICHE GEWÄHRLEISTUNG ODER BEDINGUNGEN -
 * ausdrücklich oder stillschweigend - verbreitet.
 * Die sprachspezifischen Genehmigungen und Beschränkungen
 * unter der Lizenz sind dem Lizenztext zu entnehmen.
 */

package de.ozgcloud.apilib.client_attribute;

import com.thedeanda.lorem.LoremIpsum;

import de.ozgcloud.apilib.client_attribute.OzgCloudBooleanClientAttribute.OzgCloudBooleanClientAttributeBuilder;
import de.ozgcloud.apilib.client_attribute.OzgCloudDoubleClientAttribute.OzgCloudDoubleClientAttributeBuilder;
import de.ozgcloud.apilib.client_attribute.OzgCloudLongClientAttribute.OzgCloudLongClientAttributeBuilder;
import de.ozgcloud.apilib.client_attribute.OzgCloudStringClientAttribute.OzgCloudStringClientAttributeBuilder;

public class OzgCloudClientAttributeTestFactory {

	public static final String CLIENT = LoremIpsum.getInstance().getWords(1) + "-Client";
	public static final String ATTRIBUTE_NAME = LoremIpsum.getInstance().getWords(1);
	public static final OzgCloudAccessPermission ACCESS_PERMISSION = OzgCloudAccessPermission.READ_ONLY;
	public static final Boolean BOOLEAN_VALUE = true;
	public static final String STRING_VALUE = LoremIpsum.getInstance().getWords(1);
	public static final Long LONG_VALUE = 100L;
	public static final Double DOUBLE_VALUE = 2.4;

	public static OzgCloudBooleanClientAttribute createBoolean() {
		return createBooleanBuilder().build();
	}

	public static OzgCloudBooleanClientAttributeBuilder<?, ?> createBooleanBuilder() {
		return OzgCloudBooleanClientAttribute.builder()
				.clientName(CLIENT)
				.attributeName(ATTRIBUTE_NAME)
				.access(ACCESS_PERMISSION)
				.value(BOOLEAN_VALUE);
	}

	public static  OzgCloudStringClientAttribute createString() {
		return createStringBuilder().build();
	}

	public static OzgCloudStringClientAttributeBuilder<?, ?> createStringBuilder() {
		return OzgCloudStringClientAttribute.builder()
				.clientName(CLIENT)
				.attributeName(ATTRIBUTE_NAME)
				.access(ACCESS_PERMISSION)
				.value(STRING_VALUE);
	}

	public static OzgCloudLongClientAttribute createLong() {
		return createLongBuilder().build();
	}

	public static OzgCloudLongClientAttributeBuilder<?, ?> createLongBuilder() {
		return OzgCloudLongClientAttribute.builder()
				.clientName(CLIENT)
				.attributeName(ATTRIBUTE_NAME)
				.access(ACCESS_PERMISSION)
				.value(LONG_VALUE);
	}

	public static OzgCloudDoubleClientAttribute createDouble() {
		return createDoubleBuilder().build();
	}

	public static OzgCloudDoubleClientAttributeBuilder<?, ?> createDoubleBuilder() {
		return OzgCloudDoubleClientAttribute.builder()
				.clientName(CLIENT)
				.attributeName(ATTRIBUTE_NAME)
				.access(ACCESS_PERMISSION)
				.value(DOUBLE_VALUE);
	}
}
